@@ -145,15 +145,15 @@ int sqfs_dir_reader_open_dir(sqfs_dir_reader_t *rd,
 	rd->size = size;
 	rd->entries = 0;
 
-	if (rd->size <= sizeof(rd->hdr))
-		return 0;
-
 	block_start += rd->super->directory_table_start;
 
 	rd->dir_block_start = block_start;
 	rd->dir_offset = offset;
 	rd->start_size = size;
 
+	if (rd->size <= sizeof(rd->hdr))
+		return 0;
+
 	return sqfs_meta_reader_seek(rd->meta_dir, block_start, offset);
 }
 
@@ -164,7 +164,7 @@ int sqfs_dir_reader_read(sqfs_dir_reader_t *rd, sqfs_dir_entry_t **out)
 	int err;
 
 	if (!rd->entries) {
-		if (rd->size < sizeof(rd->hdr))
+		if (rd->size <= sizeof(rd->hdr))
 			return 1;
 
 		err = sqfs_meta_reader_read_dir_header(rd->meta_dir, &rd->hdr);
@@ -175,6 +175,12 @@ int sqfs_dir_reader_read(sqfs_dir_reader_t *rd, sqfs_dir_entry_t **out)
 		rd->entries = rd->hdr.count + 1;
 	}
 
+	if (rd->size <= sizeof(*ent)) {
+		rd->size = 0;
+		rd->entries = 0;
+		return 1;
+	}
+
 	err = sqfs_meta_reader_read_dir_ent(rd->meta_dir, &ent);
 	if (err)
 		return err;
@@ -200,6 +206,9 @@ int sqfs_dir_reader_rewind(sqfs_dir_reader_t *rd)
 	rd->size = rd->start_size;
 	rd->entries = 0;
 
+	if (rd->size <= sizeof(rd->hdr))
+		return 0;
+
 	return sqfs_meta_reader_seek(rd->meta_dir, rd->dir_block_start,
 				     rd->dir_offset);
 }
